==> webkit2gtk_2.50.2.orig.tar.xz: webkitgtk-2.50.2/Source/WebCore/Modules/WebGPU/GPU.h <==
/*
 * Copyright (C) 2021-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUAdapter.h"
#include "GPURequestAdapterOptions.h"
#include "GPUTextureFormat.h"
#include "JSDOMPromiseDeferredForward.h"
#include "WebGPU.h"
#include <optional>
#include <wtf/Deque.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>

namespace WebCore {

class GPUCompositorIntegration;
class GPUPresentationContext;
struct GPUPresentationContextDescriptor;
class GraphicsContext;
class NativeImage;
class WGSLLanguageFeatures;

class GPU : public RefCounted<GPU> {
public:
    static Ref<GPU> create(Ref<WebGPU::GPU>&& backing)
    {
        return adoptRef(*new GPU(WTFMove(backing)));
    }
    ~GPU();

    using RequestAdapterPromise = DOMPromiseDeferred<IDLNullable<IDLInterface<GPUAdapter>>>;
    void requestAdapter(const std::optional<GPURequestAdapterOptions>&, RequestAdapterPromise&&);

    GPUTextureFormat getPreferredCanvasFormat() const;
    WGSLLanguageFeatures& wgslLanguageFeatures() const { return m_wgslLanguageFeatures; }

    RefPtr<GPUPresentationContext> createPresentationContext(const GPUPresentationContextDescriptor&);

    RefPtr<GPUCompositorIntegration> createCompositorIntegration();

    void paintToCanvas(NativeImage&, const IntSize&, GraphicsContext&);
private:
    GPU(Ref<WebGPU::GPU>&&);

    struct PendingRequestAdapterArguments;
    const Ref<WebGPU::GPU> m_backing;
    const Ref<WGSLLanguageFeatures> m_wgslLanguageFeatures;
};

}

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/Modules/WebGPU/GPU.h <==
/*
 * Copyright (C) 2021-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/JSDOMPromiseDeferredForward.h>
#include <WebCore/WebGPU.h>
#include <optional>
#include <wtf/Deque.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>

namespace WebCore {

class GPUAdapter;
class GPUCompositorIntegration;
class GPUPresentationContext;
struct GPUPresentationContextDescriptor;
class GraphicsContext;
class NativeImage;
class WGSLLanguageFeatures;

enum class GPUTextureFormat : uint8_t;

struct GPURequestAdapterOptions;

class GPU : public RefCounted<GPU> {
public:
    static Ref<GPU> create(Ref<WebGPU::GPU>&& backing)
    {
        return adoptRef(*new GPU(WTFMove(backing)));
    }
    ~GPU();

    using RequestAdapterPromise = DOMPromiseDeferred<IDLNullable<IDLInterface<GPUAdapter>>>;
    void requestAdapter(const std::optional<GPURequestAdapterOptions>&, RequestAdapterPromise&&);

    GPUTextureFormat getPreferredCanvasFormat() const;
    WGSLLanguageFeatures& wgslLanguageFeatures() const { return m_wgslLanguageFeatures; }

    RefPtr<GPUPresentationContext> createPresentationContext(const GPUPresentationContextDescriptor&);

    RefPtr<GPUCompositorIntegration> createCompositorIntegration();

    void paintToCanvas(NativeImage&, const IntSize&, GraphicsContext&);
    const WebGPU::GPU& backing() const { return m_backing; }
    WebGPU::GPU& backing() { return m_backing; }

private:
    GPU(Ref<WebGPU::GPU>&&);

    struct PendingRequestAdapterArguments;
    const Ref<WebGPU::GPU> m_backing;
    const Ref<WGSLLanguageFeatures> m_wgslLanguageFeatures;
};

}
